.. _install:

*******
Install
*******

Regular install
===============

To install sigc run:

.. code-block:: bash

    git clone https://github.com/seqyuan/sigc
    cd sigc
    pip install .

run this pip command to specify the version and installation source:

.. code-block:: bash

    pip install -i https://pypi.org/simple sigc==0.1.6

Checking version
================

To check your sigc version

.. code-block:: python

    import sigc
    sigc.__version__

